@@ -19,16 +19,15 @@ pretrain_model_url = {
 class CodeFormer:
     def __init__(
         self,
-        input_path: str = "./inputs/whole_imgs",
-        output_path: str = None,
         fidelity_weight=0.5,
         upscale=2,
         has_aligned=False,
         only_center_face=False,
         draw_box=False,
         detection_model="retinaface_resnet50",
-        bg_upsampler=None,
-        face_upsample=False,
+        bg_enhance=False,
+        bg_upsampler="realesrgan",
+        face_enhance=False,
         bg_tile=400,
         suffix=None,
         save_video_fps=None,
@@ -46,37 +45,37 @@ class CodeFormer:
             weights (str): Path to the pretrained model
             detection_model (str): Face detector. Optional: retinaface_resnet50, retinaface_mobile0.25, YOLOv5l, YOLOv5n, dlib.
                 Default: retinaface_resnet50
+            bg_enhance (bool): Background enhancement. Default: False
             bg_upsampler (str): Choices: Background upsampler. Optional: realesrgan
-            face_upsample (bool): Face upsampler after enhancement. Default: False
+            face_enhance (bool): Face upsampler after enhancement. Default: False
             bg_tile (int): Tile size for background sampler. Default: 400
             suffix (str): Suffix of the restored faces. Default: None
             save_video_fps (float): Frame rate for saving video. Default: None
         """
 
         self.device = get_device()
-        self.input_path = input_path
-        self.output_path = output_path
         self.fidelity_weight = fidelity_weight
         self.upscale = upscale
         self.has_aligned = has_aligned
         self.only_center_face = only_center_face
         self.draw_box = draw_box
         self.detection_model = detection_model
+        self.bg_enhance = bg_enhance
         self.bg_upsampler = bg_upsampler
-        self.face_upsample = face_upsample
+        self.face_enhance = face_enhance
         self.bg_tile = bg_tile
         self.suffix = suffix
         self.save_video_fps = save_video_fps
         self.weights = weights
 
         # ------------------ set up background upsampler ------------------
-        if bg_upsampler == "realesrgan":
+        if self.bg_enhance and self.bg_upsampler == "realesrgan":
             self.bg_upsampler = self.get_realesrgan(bg_tile)
         else:
             self.bg_upsampler = None
 
         # ------------------ set up face upsampler ------------------
-        if self.face_upsample:
+        if self.face_enhance:
             if self.bg_upsampler is not None:
                 self.face_upsampler = self.bg_upsampler
             else:
@@ -109,10 +108,10 @@ class CodeFormer:
         # if not self.has_aligned:
         #     print(f"Face detection model: {self.detection_model}")
         # if self.bg_upsampler is not None:
-        #     print(f"Background upsampling: True, Face upsampling: {self.face_upsample}")
+        #     print(f"Background upsampling: True, Face upsampling: {self.face_enhance}")
         # else:
         #     print(
-        #         f"Background upsampling: False, Face upsampling: {self.face_upsample}"
+        #         f"Background upsampling: False, Face upsampling: {self.face_enhance}"
         #     )
 
         self.face_helper = FaceRestoreHelper(
@@ -191,7 +190,7 @@ class CodeFormer:
                     bg_img = None
                 self.face_helper.get_inverse_affine(None)
                 # paste each restored face to the input image
-                if self.face_upsample and self.face_upsampler is not None:
+                if self.face_enhance and self.face_upsampler is not None:
                     restored_img = self.face_helper.paste_faces_to_input_image(
                         upsample_img=bg_img,
                         draw_box=self.draw_box,
@@ -250,7 +249,7 @@ class CodeFormer:
             warnings.warn(
                 "Running on CPU now! Make sure your PyTorch version matches your CUDA."
                 "The unoptimized RealESRGAN is slow on CPU. "
-                "If you want to disable it, please remove `--bg_upsampler` and `--face_upsample` in command.",
+                "If you want to disable it, please remove `--bg_enhance` and `--face_enhance` in command.",
                 category=RuntimeWarning,
             )
         return upsampler
